import { Component } from './component';
/**
 * `devtools` is an helper function that will expose the instance of a Component in a `$yuzu` property attached to its root DOM element.
 *
 * It will also extend every Component instance with some useful methods.
 *
 * !> To improve performance in production, this property and its methods will be available just when `process.env.NODE_ENV !== 'production'`.
 *
 * To initialize the devtools copy the following code into your entry point:
 *
 * ```js
 * import { Component, devtools } from 'yuzu';
 *
 * devtools(Component);
 * ```
 */
declare let devtools: (c: typeof Component) => void;
export declare type YuzuRoot = Element & {
    $yuzu: Component;
};
export { devtools };
