import { Component } from './component';
import { IComponentConstructable } from '../types';
export interface IExtendedComponent<P extends Component<any, any>, M extends Record<string, any>> extends IComponentConstructable<P> {
    new (options?: Record<string, any>): P & M;
}
/**
 * Utility method to create new Component classes in environments that don't support ES6 `class`es.
 *
 * @param {Component} parent Component class to extend
 * @param {object} props New component default properties and methods
 * @example
 * // UMD environment
 * const Text = YZ.extend(YZ.Component, {
 *  created: function () {
 *    this.state = { body:  '' };
 *  },
 *  mounted: function () {
 *    this.$el.innerHTML = this.state.body;
 *  }
 * });
 */
export declare function extend<P extends Component, E extends Record<string, any>>(parent: IComponentConstructable<P>, props?: E): IExtendedComponent<P, E>;
